@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 2)
+__version__ = (0, 2, 1)
 __all__ = [
     "Buffer", "SupportsRead", "SupportsReadinto", "SupportsWrite", "SupportsSeek", 
     "AsyncBufferedReader", "AsyncTextIOWrapper", 
@@ -16,7 +16,7 @@ __all__ = [
     "progress_bytes_iter", "progress_bytes_async_iter", 
 ]
 
-from asyncio import run as run_async, to_thread, Lock as AsyncLock
+from asyncio import to_thread, Lock as AsyncLock
 from collections.abc import Awaitable, AsyncIterable, AsyncIterator, Callable, Iterable, Iterator
 from functools import update_wrapper
 from io import BufferedIOBase, BufferedReader, BytesIO, RawIOBase, TextIOWrapper
@@ -45,7 +45,7 @@ except ImportError:
     Buffer.register(_SimpleCData)
     Buffer.register(array)
 
-from asynctools import async_chain, ensure_async, ensure_aiter, ensure_coroutine
+from asynctools import async_chain, ensure_async, ensure_aiter, run_async
 from property import staticproperty
 
 
@@ -164,7 +164,7 @@ class AsyncBufferedReader(BufferedReader):
         except (AttributeError, TypeError):
             ret = getattr(raw, "close")()
         if isawaitable(ret):
-            run_async(ensure_coroutine(ret))
+            run_async(ret)
 
     async def flush(self, /):
         return await ensure_async(self.raw.flush, threaded=True)()
@@ -588,7 +588,7 @@ class AsyncTextIOWrapper(TextIOWrapper):
         except (AttributeError, TypeError):
             ret = getattr(buffer, "close")()
         if isawaitable(ret):
-            run_async(ensure_coroutine(ret))
+            run_async(ret)
 
     async def flush(self, /):
         return await ensure_async(self.buffer.flush, threaded=True)()
@@ -1476,14 +1476,17 @@ def bytes_iter_to_async_reader(
         except:
             pass
     def close():
+        nonlocal at_end
         try:
             method = getattr(it, "aclose")
         except AttributeError:
             method = getattr(it, "close")
         ret = method()
         if isawaitable(ret):
-            run_async(ensure_coroutine(ret))
+            run_async(ret)
+        at_end = True
     async def aclose():
+        nonlocal at_end
         try:
             method = getattr(it, "aclose")
         except AttributeError:
@@ -1491,6 +1494,7 @@ def bytes_iter_to_async_reader(
         ret = method()
         if isawaitable(ret):
             await ret
+        at_end = True
     def peek(n: int = 0, /) -> bytearray:
         if n <= 0:
             return unconsumed[:]
